@@ -132,6 +132,7 @@ class StreamLiker(YSL):
         if self.like:
             print("Current status: Liking videos...")
             print('-' * 30)
+            no_exception = True
             for name, video_id in self.currently_streaming.items():
                 is_liked = False
                 link = "https://www.youtube.com/watch?v=" + video_id
@@ -140,17 +141,19 @@ class StreamLiker(YSL):
                 try:
                     like_button = WebDriverWait(self.driver, 10).until(
                         EC.element_to_be_clickable((By.XPATH,
-                                                    '//*[@id="top-level-buttons"]/ytd-toggle-button-renderer[1]/a/yt-icon-button/button'))
+                                                    '/html/body/ytd-app/div/ytd-page-manager/ytd-watch-flexy/div[5]/div[1]/div/div[5]/div[2]/ytd-video-primary-info-renderer/div/div/div[3]/div/ytd-menu-renderer/div[1]/ytd-toggle-button-renderer[1]/a/yt-icon-button/button/yt-icon'))
                     )
                     if like_button.get_attribute("aria-pressed") == "true":
                         is_liked = True
                         print(f"Video from {name} is already liked.")
+                #//*[@id="top-level-buttons"]/ytd-toggle-button-renderer[1]/a/yt-icon-button/button
+                # /html/body/ytd-app/div/ytd-page-manager/ytd-watch-flexy/div[5]/div[1]/div/div[5]/div[2]/ytd-video-primary-info-renderer/div/div/div[3]/div/ytd-menu-renderer/div[1]/ytd-toggle-button-renderer[1]/a/yt-icon-button/button/yt-icon
+                except Exception:
+                    print("LikeButtonError: Cannot find XPATH. URL may be invalid.")
+                    no_exception = False
+                    pass
 
-                except:
-                    self.driver_quit()
-                    assert False, "LikeButtonError: Cannot find XPATH."
-
-                if not is_liked:
+                if not is_liked and no_exception:
                     self.number_of_to_be_liked_streams += 1
                     ActionChains(self.driver).move_to_element(like_button).click(like_button).perform()
                     print(f"Video from {name} is liked.")
